@@ -63,7 +63,7 @@ def cmd_init(argv, path_to_tx):
     txrc = os.path.join(home, ".transifexrc")
     config = OrderedRawConfigParser()
 
-    default_transifex = "https://www.transifex.net"
+    default_transifex = "https://www.transifex.com"
     transifex_host = options.host or raw_input("Transifex instance [%s]: " % default_transifex)
 
     if not transifex_host:
